@@ -202,6 +202,9 @@ tb_int_t tb_demo_platform_file_main(tb_int_t argc, tb_char_t** argv)
     tb_bool_t ok = tb_file_rename(argv[1], argv[2]);
     tb_trace_i("rename: %s => %s %s", argv[1], argv[2], ok? "ok" : "failed");
 #elif 1
+    tb_long_t ok = tb_file_fscase(argv[1]);
+    tb_trace_i("fscase: %s => %d", argv[1], ok);
+#elif 0
     tb_bool_t ok = tb_file_copy(argv[1], argv[2], TB_FILE_COPY_LINK);
     tb_trace_i("copy: %s => %s %s", argv[1], argv[2], ok? "ok" : "failed");
 #elif 0
